@@ -1,11 +1,15 @@
 from django.contrib import admin
 from django.contrib.auth.admin import UserAdmin
 
-from django_boost.admin.sites import register_all
 from django_boost.forms import UserCreationForm
 from django_boost.models import EmailUser
 
-__all__ = ["EmailUserAdmin", "register_all"]
+from .mixins import LogicalDeletionModelAdminMixin
+from .sites import register_all
+
+__all__ = ["EmailUserAdmin",
+           "LogicalDeletionModelAdmin",
+           "register_all"]
 
 
 @admin.register(EmailUser)
@@ -17,3 +21,7 @@ class EmailUserAdmin(UserAdmin):
             'fields': ('email', 'password1', 'password2'),
         }),
     )
+
+
+class LogicalDeletionModelAdmin(LogicalDeletionModelAdminMixin, admin.ModelAdmin):
+    """ModelAdmin for Model that inherited LogicalDeletionModelMixin."""
