@@ -61,3 +61,16 @@ class LogicalDeletionMixin(models.Model):
             return super().delete(using=using, keep_parents=keep_parents)
         self.deleted_at = self.get_deleted_value()
         return self.save()
+
+    def revive(self, force_update=False, using=None):
+        """Revive logical deleted item."""
+        self.deleted_at = None
+        return self.save()
+
+    def is_dead(self):
+        """Return True if the item is dead."""
+        return self.deleted_at != None
+
+    def is_alive(self):
+        """Return True if record is alive, otherwise False."""
+        return self.deleted_at == None
